package com.fs.company.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.company.domain.CompanyUserDelayTime;
import org.apache.ibatis.annotations.Param;

/**
 * 员工发送延时时间关联Mapper接口
 *
 * @author fs
 * @date 2025-06-18
 */
public interface CompanyUserDelayTimeMapper extends BaseMapper<CompanyUserDelayTime>{
    /**
     * 查询员工发送延时时间关联
     *
     * @param id 员工发送延时时间关联主键
     * @return 员工发送延时时间关联
     */
    CompanyUserDelayTime selectCompanyUserDelayTimeById(Long id);

    /**
     * 查询员工发送延时时间关联列表
     *
     * @param companyUserDelayTime 员工发送延时时间关联
     * @return 员工发送延时时间关联集合
     */
    List<CompanyUserDelayTime> selectCompanyUserDelayTimeList(CompanyUserDelayTime companyUserDelayTime);

    /**
     * 新增员工发送延时时间关联
     *
     * @param companyUserDelayTime 员工发送延时时间关联
     * @return 结果
     */
    int insertCompanyUserDelayTime(CompanyUserDelayTime companyUserDelayTime);

    /**
     * 修改员工发送延时时间关联
     *
     * @param companyUserDelayTime 员工发送延时时间关联
     * @return 结果
     */
    int updateCompanyUserDelayTime(CompanyUserDelayTime companyUserDelayTime);

    /**
     * 删除员工发送延时时间关联
     *
     * @param id 员工发送延时时间关联主键
     * @return 结果
     */
    int deleteCompanyUserDelayTimeById(Long id);

    /**
     * 批量删除员工发送延时时间关联
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCompanyUserDelayTimeByIds(Long[] ids);


    /**
     * 通过销售用户id和企业id进行查询数据
     *
     * @param companyUserId
     * @param companyId
     * @return
     */
    CompanyUserDelayTime selectUserDelayTimeByCompanyUserId(@Param("companyUserId") Long companyUserId, @Param("companyId") Long companyId);
}
